@@ -1,10 +1,11 @@
-#!/usr/bin/env python3
 """
 This script tests the python class interface
 """
-import pyshtools
+import sys
+import os
+import pyshtools as pysh
 
-pyshtools.utils.figstyle()
+pysh.utils.figstyle()
 
 
 # ==== MAIN FUNCTION ====
@@ -20,7 +21,7 @@ def example1():
     lmax = 20
     nwin = 20
     theta = 25.
-    cap = pyshtools.SHWindow.from_cap(theta, lmax, nwin=nwin)
+    cap = pysh.SHWindow.from_cap(theta, lmax, nwin=nwin)
     cap.info()
     cap.plot_windows(20, show=False, fname='cap_tapers.png')
     cap.plot_coupling_matrix(30, k=5, show=False, fname='cap_coupling.png')
@@ -32,12 +33,17 @@ def example2():
     lmax = 15
     nwins = 15
 
-    coeffs = pyshtools.SHCoeffs.from_file(
-        '../../ExampleDataFiles/srtmp300.msl')
+    topofile = 'srtmp300.msl'
+    if len(sys.argv) > 1:
+        topofile = os.path.join(sys.argv[1], topofile)
+    else:
+        topofile = os.path.join('../../ExampleDataFiles', topofile)
+
+    coeffs = pysh.SHCoeffs.from_file(topofile)
     topo = coeffs.expand(grid='DH2')
     dh_mask = topo.data > 0.
     print(dh_mask.shape)
-    region = pyshtools.SHWindow.from_mask(dh_mask, lmax, nwins)
+    region = pysh.SHWindow.from_mask(dh_mask, lmax, nwins)
     region.info()
     region.plot_windows(nwins, show=False, fname='continent_tapers.png')
     region.plot_coupling_matrix(30, k=5, show=False,
