@@ -41,6 +41,9 @@ def shape_air(lmax=2160):
         Journal of Geophysical Research: Solid Earth, B05407,
         doi:10.1029/2011JB008878.
     '''
+    if lmax < 0:
+        lmax = 2160
+
     fname = _retrieve(
         url="http://ddfe.curtin.edu.au/models/Earth2012/topo_shape_to2160/Earth2012.shape_air.SHCto2160.zip",  # noqa: E501
         known_hash="sha256:07b948727c96022f40375d82cb3e505732fb3e1bf72f41b1cc072445dafab059",  # noqa: E501
@@ -68,6 +71,9 @@ def shape_bathy(lmax=2160):
         Journal of Geophysical Research: Solid Earth, B05407,
         doi:10.1029/2011JB008878.
     '''
+    if lmax < 0:
+        lmax = 2160
+
     fname = _retrieve(
         url="http://ddfe.curtin.edu.au/models/Earth2012/topo_shape_to2160/Earth2012.shape_bathy.SHCto2160.zip",  # noqa: E501
         known_hash="sha256:ee03c7addf13f60efd3c928f166f83f5a9f17991c9dd74a88c6c8d9ede8bb15e",  # noqa: E501
@@ -97,6 +103,9 @@ def shape_bathy_bed(lmax=2160):
         Journal of Geophysical Research: Solid Earth, B05407,
         doi:10.1029/2011JB008878.
     '''
+    if lmax < 0:
+        lmax = 2160
+
     fname = _retrieve(
         url="http://ddfe.curtin.edu.au/models/Earth2012/topo_shape_to2160/Earth2012.shape_bathy_bed.SHCto2160.zip",  # noqa: E501
         known_hash="sha256:66ffd58246566b4f62cc1f71145388057a4c2a1a8142f55e089e26a0b2a22d57",  # noqa: E501
@@ -125,6 +134,9 @@ def shape_ret(lmax=2160):
         Journal of Geophysical Research: Solid Earth, B05407,
         doi:10.1029/2011JB008878.
     '''
+    if lmax < 0:
+        lmax = 2160
+
     fname = _retrieve(
         url="http://ddfe.curtin.edu.au/models/Earth2012/topo_shape_to2160/Earth2012.shape_RET2012.SHCto2160.zip",  # noqa: E501
         known_hash="sha256:16c769df9d2c790fb62d1a1e73fd6070c5b5b663c2bd7f68fd21ad4aa8c96a2b",  # noqa: E501
@@ -153,6 +165,9 @@ def topo_air(lmax=2160):
         Journal of Geophysical Research: Solid Earth, B05407,
         doi:10.1029/2011JB008878.
     '''
+    if lmax < 0:
+        lmax = 2160
+
     fname = _retrieve(
         url="http://ddfe.curtin.edu.au/models/Earth2012/topo_shape_to2160/Earth2012.topo_air.SHCto2160.zip",  # noqa: E501
         known_hash="sha256:7b68053ba74246f1a755fcce05266a58ab96529b1e48309b98a0e9ba49b4ba3f",  # noqa: E501
@@ -182,6 +197,9 @@ def topo_bathy(lmax=2160):
         Journal of Geophysical Research: Solid Earth, B05407,
         doi:10.1029/2011JB008878.
     '''
+    if lmax < 0:
+        lmax = 2160
+
     fname = _retrieve(
         url="http://ddfe.curtin.edu.au/models/Earth2012/topo_shape_to2160/Earth2012.topo_bathy.SHCto2160.zip",  # noqa: E501
         known_hash="sha256:997a16f85dafbfd1a0ee2339f503470acea6c8cb8eecdf5f2e057904a97f9718",  # noqa: E501
@@ -212,6 +230,9 @@ def topo_bathy_bed(lmax=2160):
         Journal of Geophysical Research: Solid Earth, B05407,
         doi:10.1029/2011JB008878.
     '''
+    if lmax < 0:
+        lmax = 2160
+
     fname = _retrieve(
         url="http://ddfe.curtin.edu.au/models/Earth2012/topo_shape_to2160/Earth2012.topo_bathy_bed.SHCto2160.zip",  # noqa: E501
         known_hash="sha256:f8b0535a76de11de767d0ebb6c032f5983ac48ad29d1750b0d22e15a627f88e1",  # noqa: E501
@@ -240,6 +261,9 @@ def ret(lmax=2160):
         Journal of Geophysical Research: Solid Earth, B05407,
         doi:10.1029/2011JB008878.
     '''
+    if lmax < 0:
+        lmax = 2160
+
     fname = _retrieve(
         url="http://ddfe.curtin.edu.au/models/Earth2012/topo_shape_to2160/Earth2012.RET2012.SHCto2160.zip",  # noqa: E501
         known_hash="sha256:36b3204d86fa01fa9e8f693e2df8e91905b67619a0192cc0c269be21a7ba5799",  # noqa: E501
