@@ -34,12 +34,25 @@ MakeGridGLQC   Create a 2D complex map from a set of complex spherical harmonic
 GLQGridCoord   Compute the latitude and longitude coordinates used in Gauss-
                Legendre quadrature grids.
 
+Least squares inversion
+-----------------------
+shlsq          Generic function for computing the spherical harmonic
+               coefficients by least squares inversion.
+SHExpandLSQ    Determine the spherical harmonic coefficients of an irregularly
+               sampled function using a least squares inversion.
+SHExpandLSQ_G  Determine the spherical harmonic coefficients of an irregularly
+               sampled function using a least squares inversion with a
+               precomputed data kernel matrix.
+SHExpandWLSQ   Determine the spherical harmonic coefficients of an irregularly
+               sampled function using a weighted least squares inversion.
+SHExpandLSQ_G  Determine the spherical harmonic coefficients of an irregularly
+               sampled function using a weighted least squares inversion with a
+               precomputed data kernel matrix.
+LSQ_G          Compute the data kernel matrix G that is used when computing
+               spherical harmonic coefficients by least squares inversion.
+
 Other
 -----
-SHExpandLSQ    Expand a set of irregularly sampled data points into spherical
-               harmonics using a least squares inversion.
-SHExpandWLSQ   Expand a set of irregularly sampled data points into spherical
-               harmonics using a weighted least squares inversion.
 MakeGrid2D     Create a 2D cylindrical map with arbitrary grid spacing from a
                set of spherical harmonic coefficients.
 MakeGridPoint  Evaluate a real function expressed in real spherical harmonics
@@ -56,7 +69,10 @@ spharm_lm      Compute the spherical harmonic function for a specific degree l
 from ..backends.shtools import SHGLQ
 from ..backends.shtools import GLQGridCoord
 from ..backends.shtools import SHExpandLSQ
+from ..backends.shtools import SHExpandLSQ_G
 from ..backends.shtools import SHExpandWLSQ
+from ..backends.shtools import SHExpandWLSQ_G
+from ..backends.shtools import LSQ_G
 from ..backends.shtools import MakeGrid2D
 from ..backends.shtools import MakeGridPoint
 from ..backends.shtools import MakeGridPointC
@@ -64,10 +80,12 @@ from ..backends.shtools import SHMultiply
 
 from .spharm_functions import spharm
 from .spharm_functions import spharm_lm
+from .sh_least_squares import shlsq
 
 from ..backends import backend_module, select_preferred_backend
 
 del spharm_functions  # noqa: F821
+del sh_least_squares  # noqa: F821
 
 
 def inject_backend_specific_functions_for_expand():
@@ -98,6 +116,7 @@ select_preferred_backend()
 # ---- Define __all__ for use with: from pyshtools import * ----
 __all__ = ['SHExpandDH', 'MakeGridDH', 'SHExpandDHC', 'MakeGridDHC',
            'SHGLQ', 'SHExpandGLQ', 'MakeGridGLQ', 'SHExpandGLQC',
-           'MakeGridGLQC', 'GLQGridCoord', 'SHExpandLSQ', 'SHExpandWLSQ',
+           'MakeGridGLQC', 'GLQGridCoord', 'shlsq', 'SHExpandLSQ',
+           'SHExpandLSQ_G', 'SHExpandWLSQ', 'SHExpandWLSQ_G', 'LSQ_G',
            'MakeGrid2D', 'MakeGridPoint', 'MakeGridPointC', 'SHMultiply',
            'MakeGradientDH', 'spharm', 'spharm_lm']
