@@ -1,5 +1,5 @@
 """
-    Class for the height of the geoid.
+Class for the height of the geoid.
 """
 import numpy as _np
 import copy as _copy
@@ -13,10 +13,11 @@ class SHGeoid(object):
     """
     Class for the height of the geoid. The class is initialized from a class
     instance of SHGravCoeffs using the method geoid(). Geoid heights are
-    referenced to a flattened ellipsoid of semimajor axis a and flattening f.
+    with respect to a flattened ellipsoid of semimajor axis a and flattening f.
 
     Attributes:
 
+    name           : The name of the dataset.
     geoid          : SHGrid class instance of the geoid.
     gm             : Gravitational constant time the mass of the body.
     potref         : Potential of the chosen geoid, in m2/s2.
@@ -35,9 +36,9 @@ class SHGeoid(object):
     sampling       : The longitudinal sampling for Driscoll and Healy grids.
                      Either 1 for equally sampled grids (nlat=nlon) or 2 for
                      equally spaced grids in degrees.
-    units          : The units of the gridded data.
     extend         : True if the grid contains the redundant column for 360 E
                      and the unnecessary row for 90 S.
+    units          : The units of the gridded data.
     epoch          : The epoch time of the gravity model.
 
     Methods:
@@ -50,7 +51,7 @@ class SHGeoid(object):
     info()         : Print a summary of the data stored in the SHGrid instance.
     """
     def __init__(self, geoid, gm, potref, a, f, omega, r, order, lmax,
-                 lmax_calc, units=None, epoch=None):
+                 lmax_calc, name=None, units=None, epoch=None):
         """
         Initialize the SHGeoid class.
         """
@@ -73,6 +74,7 @@ class SHGeoid(object):
         self.r = r
         self.lmax = lmax
         self.lmax_calc = lmax_calc
+        self.name = name
         self.units = units
         self.epoch = epoch
 
@@ -97,35 +99,31 @@ class SHGeoid(object):
         print(repr(self))
 
     def __repr__(self):
-        str = ('grid = {:s}\n'
-               'sampling = {:d}\n'
-               'nlat = {:d}\n'
-               'nlon = {:d}\n'
-               'n = {:d}\n'
-               'sampling = {:d}\n'
-               'extend = {}\n'
-               'lmax = {:d}\n'
-               'lmax_calc = {:d}\n'
-               'gm (m3 / s2) = {:e}\n'
-               'reference potential (m2 /s2) = {:e}\n'
-               'a (m)= {:e}\n'
-               'f = {:e}\n'
-               'omega (rad / s) = {:s}\n'
-               'radius of Taylor expansion (m) = {:e}\n'
-               'order of expansion = {:d}\n'
-               'units = {:s}\n'
-               'epoch = {:s}'
-               .format(repr(self.grid), self.sampling, self.nlat, self.nlon,
-                       self.n, self.sampling, self.extend, self.lmax,
-                       self.lmax_calc, self.gm, self.potref, self.a, self.f,
-                       repr(self.omega), self.r, self.order, repr(self.units),
-                       repr(self.epoch)))
-        return str
+        return (f'  name = {self.name!r}\n'
+                f'  grid = {self.grid!r}\n'
+                f'  sampling = {self.sampling}\n'
+                f'  nlat = {self.nlat}\n'
+                f'  nlon = {self.nlon}\n'
+                f'  n = {self.n}\n'
+                f'  extend = {self.extend}\n'
+                f'  lmax = {self.lmax}\n'
+                f'  lmax_calc = {self.lmax_calc}\n'
+                f'  gm (m3 / s2) = {self.gm}\n'
+                f'  reference potential (m2 /s2) = {self.potref}\n'
+                f'  a (m)= {self.a}\n'
+                f'  f = {self.f}\n'
+                f'  omega (rad / s) = {self.omega}\n'
+                f'  radius of Taylor expansion (m) = {self.r}\n'
+                f'  order of expansion = {self.order}\n'
+                f'  units = {self.units!r}\n'
+                f'  epoch = {self.epoch}'
+                )
 
     def plot(self, projection=None, tick_interval=[30, 30],
              minor_tick_interval=[None, None], xlabel=None, ylabel=None,
-             title=None, titlesize=None, colorbar='right', cmap='viridis',
-             cmap_limits=None, cmap_reverse=False, cb_triangles='neither',
+             title=None, titlesize=None, title_offset=None, colorbar='right',
+             cmap='viridis', cmap_limits=None, cmap_rlimits=None,
+             cmap_reverse=False, cmap_scale='lin', cb_triangles='neither',
              cb_label='geoid, m', cb_tick_interval=None, grid=False,
              axes_labelsize=None, tick_labelsize=None, show=True, ax=None,
              cb_minor_tick_interval=None, ticks='WSen', cb_ylabel=None,
@@ -136,11 +134,11 @@ class SHGeoid(object):
         Usage
         -----
         x.plot([projection, tick_interval, minor_tick_interval, ticks,
-                xlabel, ylabel, title, colorbar, cmap, cmap_limits,
-                cmap_reverse, cb_triangles, cb_label, cb_ylabel,
-                cb_tick_interval, cb_minor_tick_interval, cb_offset, cb_width,
-                grid, titlesize, axes_labelsize, tick_labelsize, ax, show,
-                fname])
+                xlabel, ylabel, title, title_offset, colorbar, cmap,
+                cmap_limits, cmap_rlimits, cmap_reverse, cmap_scale,
+                cb_triangles, cb_label, cb_ylabel, cb_tick_interval,
+                cb_minor_tick_interval, cb_offset, cb_width, grid, titlesize,
+                axes_labelsize, tick_labelsize, ax, show, fname])
 
         Parameters
         ----------
@@ -164,6 +162,8 @@ class SHGeoid(object):
             Label for the latitude axis.
         title : str or list, optional, default = None
             The title of the plot.
+        title_offset : float, optional, default = None
+            The offset between the title and top of the plot in points.
         colorbar : str, optional, default = 'right'
             Plot a colorbar along the 'top', 'right', 'bottom', or 'left' axis.
         cmap : str, optional, default = 'viridis'
@@ -173,9 +173,14 @@ class SHGeoid(object):
             and optionally an interval for each color band. If the interval is
             specified, the number of discrete colors will be
             (cmap_limits[1]-cmap_limits[0])/cmap_limits[2].
+        cmap_rlimits : list, optional, default = None
+           Same as cmap_limits, except the provided upper and lower values are
+           relative with respect to the maximum value of the data.
         cmap_reverse : bool, optional, default = False
             Set to True to reverse the sense of the color progression in the
             color table.
+        cmap_scale : str, optional, default = 'lin'
+            Scale of the color axis: 'lin' for linear or 'log' for logarithmic.
         cb_triangles : str, optional, default = 'neither'
             Add triangles to the edges of the colorbar for minimum and maximum
             values. Can be 'neither', 'both', 'min', or 'max'.
@@ -214,21 +219,24 @@ class SHGeoid(object):
                                tick_interval=tick_interval,
                                minor_tick_interval=minor_tick_interval,
                                xlabel=xlabel, ylabel=ylabel, title=title,
-                               titlesize=titlesize, colorbar=colorbar,
-                               cmap=cmap, cmap_limits=cmap_limits,
-                               cmap_reverse=cmap_reverse, cb_offset=cb_offset,
+                               titlesize=titlesize, title_offset=title_offset,
+                               colorbar=colorbar, cmap=cmap,
+                               cmap_limits=cmap_limits,
+                               cmap_rlimits=cmap_rlimits,
+                               cmap_reverse=cmap_reverse,
+                               cmap_scale=cmap_scale, cb_offset=cb_offset,
                                cb_triangles=cb_triangles, cb_label=cb_label,
                                cb_tick_interval=cb_tick_interval, grid=grid,
                                cb_ylabel=cb_ylabel, ticks=ticks,
                                cb_minor_tick_interval=cb_minor_tick_interval,
                                axes_labelsize=axes_labelsize,
                                cb_width=cb_width,
-                               tick_labelsize=tick_labelsize, ax=ax,
-                               show=show, fname=fname)
+                               tick_labelsize=tick_labelsize, ax=ax, show=show,
+                               fname=fname)
 
     def to_netcdf(self, filename=None, title='', description='',
                   comment='pyshtools grid', name='geoid',
-                  dtype='f'):
+                  dtype='d'):
         """
         Return the gridded data as a netcdf formatted file or object.
 
@@ -238,7 +246,7 @@ class SHGeoid(object):
 
         Parameters
         ----------
-        filename : str, optional, default = None
+        filename : str or pathlib.Path, optional, default = None
             Name of output file.
         title : str, optional, default = ''
             Title of the dataset.
@@ -248,7 +256,7 @@ class SHGeoid(object):
             Additional information about how the data were generated.
         name : str, optional, default = 'data'
             Name of the data array.
-        dtype : str, optional, default = 'f'
+        dtype : str, optional, default = 'd'
             Data type of the output array. Either 'f' or 'd' for single or
             double precision floating point, respectively.
         """
