@@ -1,5 +1,5 @@
 """
-    Class for grids of the two components of the horizontal gradient.
+Class for grids of the two components of the horizontal gradient.
 """
 import matplotlib as _mpl
 import matplotlib.pyplot as _plt
@@ -17,11 +17,11 @@ class SHGradient(object):
 
     Attributes:
 
+    name           : The name of the dataset.
     theta          : SHGrid class instance of the theta component of the
                      horizontal gradient.
     phi            : SHGrid class instance of the phi component of the
                      horizontal gradient.
-    units          : The units of the gridded data.
     lmax           : The maximum spherical harmonic degree resolvable by the
                      grids.
     lmax_calc      : The maximum spherical harmonic degree of the function
@@ -33,6 +33,7 @@ class SHGradient(object):
                      equally spaced grids in degrees.
     extend         : True if the grid contains the redundant column for 360 E
                      and the unnecessary row for 90 S.
+    units          : The units of the gridded data.
 
     Methods:
 
@@ -46,7 +47,7 @@ class SHGradient(object):
     """
 
     def __init__(self, theta, phi, lmax, lmax_calc, units=None,
-                 pot_units=None, epoch=None):
+                 pot_units=None, epoch=None, name=None):
         """
         Initialize the SHGradient class.
         """
@@ -61,6 +62,7 @@ class SHGradient(object):
         self.lmax = lmax
         self.lmax_calc = lmax_calc
         self.units = units
+        self.name = name
 
     def copy(self):
         """
@@ -83,24 +85,23 @@ class SHGradient(object):
         print(repr(self))
 
     def __repr__(self):
-        str = ('grid = {:s}\n'
-               'nlat = {:d}\n'
-               'nlon = {:d}\n'
-               'n = {:d}\n'
-               'sampling = {:d}\n'
-               'extend = {}\n'
-               'lmax = {:d}\n'
-               'lmax_calc = {:d}\n'
-               'units = {:s}'
-               .format(self.grid, self.nlat, self.nlon, self.n, self.sampling,
-                       self.extend, self.lmax, self.lmax_calc,
-                       repr(self.units)))
-        return str
+        return (f'  name = {self.name!r}\n'
+                f'  grid = {self.grid!r}\n'
+                f'  nlat = {self.nlat}\n'
+                f'  nlon = {self.nlon}\n'
+                f'  n = {self.n}\n'
+                f'  sampling = {self.sampling}\n'
+                f'  extend = {self.extend}\n'
+                f'  lmax = {self.lmax}\n'
+                f'  lmax_calc = {self.lmax_calc}\n'
+                f'  units = {self.units!r}'
+                )
 
     def plot_theta(self, projection=None, tick_interval=[30, 30],
                    minor_tick_interval=[None, None], xlabel=None, ylabel=None,
-                   title=None, titlesize=None, colorbar='right',
-                   cmap='viridis', cmap_limits=None, cmap_reverse=False,
+                   title=None, titlesize=None, title_offset=None,
+                   colorbar='right', cmap='viridis', cmap_limits=None,
+                   cmap_rlimits=None, cmap_reverse=False, cmap_scale='lin',
                    cb_triangles='neither', cb_label='$\\theta$ component',
                    cb_tick_interval=None, grid=False, axes_labelsize=None,
                    tick_labelsize=None, show=True, ax=None, cb_offset=None,
@@ -112,11 +113,12 @@ class SHGradient(object):
         Usage
         -----
         x.plot_theta([projection, tick_interval, minor_tick_interval, ticks,
-                      xlabel, ylabel, title, colorbar, cmap, cmap_limits,
-                      cmap_reverse, cb_triangles, cb_label, cb_ylabel,
-                      cb_tick_interval, cb_minor_tick_interval, cb_offset,
-                      cb_width, grid, titlesize, axes_labelsize,
-                      tick_labelsize, ax, show, fname])
+                      xlabel, ylabel, title, title_offset, colorbar, cmap,
+                      cmap_limits, cmap_rlimits, cmap_reverse, cmap_scale,
+                      cb_triangles, cb_label, cb_ylabel, cb_tick_interval,
+                      cb_minor_tick_interval, cb_offset, cb_width, grid,
+                      titlesize, axes_labelsize, tick_labelsize, ax, show,
+                      fname])
 
         Parameters
         ----------
@@ -140,6 +142,8 @@ class SHGradient(object):
             Label for the latitude axis.
         title : str or list, optional, default = None
             The title of the plot.
+        title_offset : float, optional, default = None
+            The offset between the title and top of the plot in points.
         colorbar : str, optional, default = 'right'
             Plot a colorbar along the 'top', 'right', 'bottom', or 'left' axis.
         cmap : str, optional, default = 'viridis'
@@ -149,9 +153,14 @@ class SHGradient(object):
             and optionally an interval for each color band. If the interval is
             specified, the number of discrete colors will be
             (cmap_limits[1]-cmap_limits[0])/cmap_limits[2].
+        cmap_rlimits : list, optional, default = None
+           Same as cmap_limits, except the provided upper and lower values are
+           relative with respect to the maximum value of the data.
         cmap_reverse : bool, optional, default = False
             Set to True to reverse the sense of the color progression in the
             color table.
+        cmap_scale : str, optional, default = 'lin'
+            Scale of the color axis: 'lin' for linear or 'log' for logarithmic.
         cb_triangles : str, optional, default = 'neither'
             Add triangles to the edges of the colorbar for minimum and maximum
             values. Can be 'neither', 'both', 'min', or 'max'.
@@ -183,16 +192,19 @@ class SHGradient(object):
         show : bool, optional, default = True
             If True, plot the image to the screen.
         fname : str, optional, default = None
-            If present, and if axes is not specified, save the image to the
+            If present, and if ax is not specified, save the image to the
             specified file.
         """
         return self.theta.plot(projection=projection,
                                tick_interval=tick_interval,
                                minor_tick_interval=minor_tick_interval,
                                xlabel=xlabel, ylabel=ylabel, title=title,
-                               titlesize=titlesize, colorbar=colorbar,
-                               cmap=cmap, cmap_limits=cmap_limits,
-                               cmap_reverse=cmap_reverse, cb_offset=cb_offset,
+                               titlesize=titlesize, title_offset=title_offset,
+                               colorbar=colorbar, cmap=cmap,
+                               cmap_limits=cmap_limits,
+                               cmap_rlimits=cmap_rlimits,
+                               cmap_reverse=cmap_reverse,
+                               cmap_scale=cmap_scale, cb_offset=cb_offset,
                                cb_triangles=cb_triangles, cb_label=cb_label,
                                cb_tick_interval=cb_tick_interval, grid=grid,
                                axes_labelsize=axes_labelsize,
@@ -204,8 +216,9 @@ class SHGradient(object):
 
     def plot_phi(self, projection=None, tick_interval=[30, 30],
                  minor_tick_interval=[None, None], xlabel=None, ylabel=None,
-                 title=None, titlesize=None, colorbar='right',
-                 cmap='viridis', cmap_limits=None, cmap_reverse=False,
+                 title=None, titlesize=None, title_offset=None,
+                 colorbar='right', cmap='viridis', cmap_limits=None,
+                 cmap_rlimits=None, cmap_scale='lin', cmap_reverse=False,
                  cb_triangles='neither', cb_label='$\\phi$ component',
                  cb_tick_interval=None, grid=False, axes_labelsize=None,
                  tick_labelsize=None, show=True, ax=None, cb_offset=None,
@@ -217,11 +230,12 @@ class SHGradient(object):
         Usage
         -----
         x.plot_phi([projection, tick_interval, minor_tick_interval, ticks,
-                    xlabel, ylabel, title, colorbar, cmap, cmap_limits,
-                    cmap_reverse, cb_triangles, cb_label, cb_ylabel,
-                    cb_tick_interval, cb_minor_tick_interval, cb_offset,
-                    cb_width, grid, titlesize, axes_labelsize, tick_labelsize,
-                    ax, show, fname])
+                    xlabel, ylabel, title, title_offset, colorbar, cmap,
+                    cmap_limits, cmap_rlimits, cmap_reverse, cmap_scale,
+                    cb_triangles, cb_label, cb_ylabel, cb_tick_interval,
+                    cb_minor_tick_interval, cb_offset, cb_width, grid,
+                    titlesize, axes_labelsize, tick_labelsize, ax, show,
+                    fname])
 
         Parameters
         ----------
@@ -245,6 +259,8 @@ class SHGradient(object):
             Label for the latitude axis.
         title : str or list, optional, default = None
             The title of the plot.
+        title_offset : float, optional, default = None
+            The offset between the title and top of the plot in points.
         colorbar : str, optional, default = 'right'
             Plot a colorbar along the 'top', 'right', 'bottom', or 'left' axis.
         cmap : str, optional, default = 'viridis'
@@ -254,9 +270,14 @@ class SHGradient(object):
             and optionally an interval for each color band. If the interval is
             specified, the number of discrete colors will be
             (cmap_limits[1]-cmap_limits[0])/cmap_limits[2].
+        cmap_rlimits : list, optional, default = None
+           Same as cmap_limits, except the provided upper and lower values are
+           relative with respect to the maximum value of the data.
         cmap_reverse : bool, optional, default = False
             Set to True to reverse the sense of the color progression in the
             color table.
+        cmap_scale : str, optional, default = 'lin'
+            Scale of the color axis: 'lin' for linear or 'log' for logarithmic.
         cb_triangles : str, optional, default = 'neither'
             Add triangles to the edges of the colorbar for minimum and maximum
             values. Can be 'neither', 'both', 'min', or 'max'.
@@ -288,17 +309,20 @@ class SHGradient(object):
         show : bool, optional, default = True
             If True, plot the image to the screen.
         fname : str, optional, default = None
-            If present, and if axes is not specified, save the image to the
+            If present, and if ax is not specified, save the image to the
             specified file.
         """
         return self.phi.plot(projection=projection,
                              tick_interval=tick_interval,
                              minor_tick_interval=minor_tick_interval,
                              xlabel=xlabel, ylabel=ylabel, title=title,
-                             titlesize=titlesize, colorbar=colorbar,
-                             cmap=cmap, cmap_limits=cmap_limits,
-                             cmap_reverse=cmap_reverse, cb_offset=cb_offset,
-                             cb_triangles=cb_triangles, cb_label=cb_label,
+                             titlesize=titlesize, title_offset=title_offset,
+                             colorbar=colorbar, cmap=cmap,
+                             cmap_limits=cmap_limits,
+                             cmap_rlimits=cmap_rlimits,
+                             cmap_reverse=cmap_reverse, cmap_scale=cmap_scale,
+                             cb_offset=cb_offset, cb_triangles=cb_triangles,
+                             cb_label=cb_label,
                              cb_tick_interval=cb_tick_interval, grid=grid,
                              axes_labelsize=axes_labelsize,
                              cb_ylabel=cb_ylabel, ticks=ticks,
@@ -308,11 +332,12 @@ class SHGradient(object):
                              show=show, fname=fname)
 
     def plot(self, projection=None, tick_interval=[60, 30],
-             minor_tick_interval=[None, None], xlabel='Longitude',
-             ylabel='Latitude', colorbar='bottom', cmap='viridis',
-             cmap_limits=None, cmap_reverse=False, cb_triangles='neither',
-             cb_tick_interval=None, grid=False, axes_labelsize=9,
-             tick_labelsize=8, show=True, cb_offset=None,
+             minor_tick_interval=[None, None], titlesize=None,
+             title_offset=None, xlabel='Longitude', ylabel='Latitude',
+             colorbar='bottom', cmap='viridis', cmap_limits=None,
+             cmap_rlimits=None, cmap_reverse=False, cmap_scale='lin',
+             cb_triangles='neither', cb_tick_interval=None, grid=False,
+             axes_labelsize=9, tick_labelsize=8, show=True, cb_offset=None,
              cb_minor_tick_interval=None, ticks='WSen', cb_ylabel=None,
              cb_width=None, fname=None):
         """
@@ -320,11 +345,12 @@ class SHGradient(object):
 
         Usage
         -----
-        x.plot([projection, tick_interval, minor_tick_interval, ticks, xlabel,
-                ylabel, colorbar, cmap, cmap_limits, cmap_reverse,
-                cb_triangles, cb_ylabel, cb_tick_interval,
-                cb_minor_tick_interval, cb_offset, cb_width, grid,
-                axes_labelsize, tick_labelsize, show, fname])
+        x.plot([projection, tick_interval, minor_tick_interval, ticks,
+                title_offset, xlabel, ylabel, colorbar, cmap, cmap_limits,
+                cmap_rlimits, cmap_reverse, cmap_scale, cb_triangles,
+                cb_ylabel, cb_tick_interval, cb_minor_tick_interval,
+                cb_offset, cb_width, grid, titlesize, axes_labelsize,
+                tick_labelsize, show, fname])
 
         Parameters
         ----------
@@ -342,6 +368,8 @@ class SHGradient(object):
             letters plot the ticks and annotations, whereas small letters plot
             only the ticks. 'W', 'S', 'E', and 'N' denote the west, south, east
             and north boundaries of the plot.
+        title_offset : float, optional, default = None
+            The offset between the title and top of the plot in points.
         xlabel : str, optional, default = 'longitude'
             Label for the longitude axis.
         ylabel : str, optional, default = 'latitude'
@@ -355,9 +383,14 @@ class SHGradient(object):
             and optionally an interval for each color band. If the interval is
             specified, the number of discrete colors will be
             (cmap_limits[1]-cmap_limits[0])/cmap_limits[2].
+        cmap_rlimits : list, optional, default = None
+           Same as cmap_limits, except the provided upper and lower values are
+           relative with respect to the maximum value of the data.
         cmap_reverse : bool, optional, default = False
             Set to True to reverse the sense of the color progression in the
             color table.
+        cmap_scale : str, optional, default = 'lin'
+            Scale of the color axis: 'lin' for linear or 'log' for logarithmic.
         cb_triangles : str, optional, default = 'neither'
             Add triangles to the edges of the colorbar for minimum and maximum
             values. Can be 'neither', 'both', 'min', or 'max'.
@@ -376,6 +409,8 @@ class SHGradient(object):
             horizontal colorbars, respectively.
         grid : bool, optional, default = False
             If True, plot major grid lines.
+        titlesize : int, optional, default = None
+            The font size of the title.
         axes_labelsize : int, optional, default = None
             The font size for the x and y axes labels.
         tick_labelsize : int, optional, default = None
@@ -383,7 +418,7 @@ class SHGradient(object):
         show : bool, optional, default = True
             If True, plot the image to the screen.
         fname : str, optional, default = None
-            If present, and if axes is not specified, save the image to the
+            If present, and if ax is not specified, save the image to the
             specified file.
         """
         if colorbar is not None:
@@ -400,9 +435,11 @@ class SHGradient(object):
         self.plot_theta(projection=projection, ax=ax.flat[0],
                         tick_interval=tick_interval,
                         minor_tick_interval=minor_tick_interval,
+                        title_offset=title_offset,
                         xlabel=xlabel, ylabel=ylabel, title=None,
-                        titlesize=None, colorbar=colorbar,
+                        titlesize=titlesize, colorbar=colorbar,
                         cmap=cmap, cmap_limits=cmap_limits,
+                        cmap_rlimits=cmap_rlimits, cmap_scale=cmap_scale,
                         cmap_reverse=cmap_reverse, cb_triangles=cb_triangles,
                         cb_tick_interval=cb_tick_interval,
                         grid=grid, axes_labelsize=axes_labelsize,
@@ -414,8 +451,9 @@ class SHGradient(object):
                       tick_interval=tick_interval,
                       minor_tick_interval=minor_tick_interval,
                       xlabel=xlabel, ylabel=ylabel, title=None,
-                      titlesize=None, colorbar=colorbar,
-                      cmap=cmap, cmap_limits=cmap_limits,
+                      title_offset=title_offset, titlesize=titlesize,
+                      colorbar=colorbar, cmap=cmap, cmap_limits=cmap_limits,
+                      cmap_rlimits=cmap_rlimits, cmap_scale=cmap_scale,
                       cmap_reverse=cmap_reverse, cb_triangles=cb_triangles,
                       cb_tick_interval=cb_tick_interval,
                       grid=grid, axes_labelsize=axes_labelsize,
