@@ -9,6 +9,7 @@ import zipfile as _zipfile
 import numpy as _np
 import requests as _requests
 import shutil as _shutil
+from pathlib import Path
 
 
 def read_dov(filename, lmax=None, error=False, header=False, header2=False,
@@ -40,7 +41,7 @@ def read_dov(filename, lmax=None, error=False, header=False, header2=False,
 
     Parameters
     ----------
-    filename : str
+    filename : str or pathlib.Path
         File name or URL that contains the text-formatted spherical harmonic
         coefficients. filename will be treated as a URL if it starts with
         'http://', 'https://', or 'ftp://'. If filename ends with '.gz' or
@@ -102,6 +103,9 @@ def read_dov(filename, lmax=None, error=False, header=False, header2=False,
     file are supported. Note that reading '.gz' and '.zip' files will be
     extremely slow if lmax is not specified.
     """
+    if isinstance(filename, Path):
+        filename = str(filename)
+
     if _isurl(filename):
         _response = _requests.get(filename)
         if filename[-4:] == '.zip':
@@ -145,7 +149,7 @@ def read_dov(filename, lmax=None, error=False, header=False, header2=False,
                 while f.read(1) != b'\n':
                     try:
                         f.seek(-2, _os.SEEK_CUR)
-                    except:
+                    except Exception:
                         f.seek(-1, _os.SEEK_CUR)  # beginning of file
                         break
 
@@ -162,7 +166,7 @@ def read_dov(filename, lmax=None, error=False, header=False, header2=False,
                     line = line.replace(',', ' ')
                     try:
                         f.seek(-len(line)-2, _os.SEEK_CUR)
-                    except:
+                    except Exception:
                         raise RuntimeError('Encountered beginning of file '
                                            'while attempting to determine '
                                            'lmax.')
@@ -357,7 +361,7 @@ def write_dov(filename, coeffs, errors=None, header=None, header2=None,
 
     Parameters
     ----------
-    filename : str
+    filename : str or pathlib.Path
         File name of the 'dov'-formatted spherical harmonic coefficients. If
         filename ends with '.gz' the file will be automatically compressed with
         gzip.
@@ -402,6 +406,9 @@ def write_dov(filename, coeffs, errors=None, header=None, header2=None,
     If the filename ends with '.gz', the file will be automatically compressed
     using gzip.
     """
+    if isinstance(filename, Path):
+        filename = str(filename)
+
     if lmax is None:
         lmax = coeffs.shape[1] - 1
     else:
