@@ -47,25 +47,29 @@ def cross_spectrum(clm1, clm2, normalization='4pi', degrees=None, lmax=None,
 
     Notes
     -----
-    This function returns either the cross-power spectrum, cross-energy
-    spectrum, or l2-cross-norm spectrum. Total cross-power is defined as the
-    integral of the clm1 times the conjugate of clm2 over all space, divided
-    by the area the functions span. If the mean of the functions is zero,
-    this is equivalent to the covariance of the two functions. The total
-    cross-energy is the integral of clm1 times the conjugate of clm2 over all
-    space and is 4pi times the total power. The l2-cross-norm is the
-    sum of clm1 times the conjugate of clm2 over all angular orders as a
-    function of spherical harmonic degree.
+    This method returns either the cross-power spectrum, cross-energy spectrum,
+    or l2-cross-norm spectrum of two functions expressed in spherical
+    harmonics. Total cross-power is defined as the integral of the first
+    function times the conjugate of the second function over all space,
+    divided by the area the functions span. If the means of the two functions
+    are zero, this is equivalent to the covariance of the two functions. The
+    total cross-energy is the integral of the first function times the
+    conjugate of the second function over all space and is 4 pi times the total
+    power. For normalized coefficients ('4pi', 'ortho', or 'schmidt'), the
+    l2-cross norm is the sum of the magnitude of the coefficients of the first
+    function multiplied by the conjugate of the coefficients of the second
+    function.
 
     The output spectrum can be expresed using one of three units. 'per_l'
-    returns the contribution to the total spectrum from all angular orders
-    at degree l. 'per_lm' returns the average contribution to the total
-    spectrum from a single coefficient at degree l, and is equal to the
-    'per_l' spectrum divided by (2l+1). 'per_dlogl' returns the contribution to
-    the total spectrum from all angular orders over an infinitessimal
-    logarithmic degree band. The contrubution in the band dlog_a(l) is
-    spectrum(l, 'per_dlogl')*dlog_a(l), where a is the base, and where
-    spectrum(l, 'per_dlogl) is equal to spectrum(l, 'per_l')*l*log(a).
+    returns the contribution to the total power, energy or l2-norm from all
+    angular orders at degree l. 'per_lm' returns the average contribution to
+    the total power, energy or l2-norm from a single coefficient at degree l,
+    and is equal to the 'per_l' spectrum divided by (2l+1). 'per_dlogl' returns
+    the contribution to the total power, energy or l2-norm from all angular
+    orders over an infinitessimal logarithmic degree band. The contrubution in
+    the band dlog_a(l) is spectrum(l, 'per_dlogl')*dlog_a(l), where a is the
+    base, and where spectrum(l, 'per_dlogl) is equal to
+    spectrum(l, 'per_l')*l*log(a).
     """
     if normalization.lower() not in ('4pi', 'ortho', 'schmidt', 'unnorm'):
         raise ValueError("The normalization must be '4pi', 'ortho', " +
@@ -131,15 +135,11 @@ def cross_spectrum(clm1, clm2, normalization='4pi', degrees=None, lmax=None,
                 array[i] = (clm1[0, l, 0:l + 1] * clm2[0, l, 0:l + 1]).sum() \
                            + (clm1[1, l, 1:l + 1] * clm2[1, l, 1:l + 1]).sum()
 
-        if convention.lower() == 'l2norm':
-            return array
-        else:
-            if normalization.lower() == '4pi':
-                pass
-            elif normalization.lower() == 'schmidt':
-                array /= (2. * degrees + 1.)
-            elif normalization.lower() == 'ortho':
-                array /= (4. * _np.pi)
+        if normalization.lower() == 'schmidt':
+            array /= (2. * degrees + 1.)
+
+        if normalization.lower() == 'ortho':
+            array /= (4. * _np.pi)
 
     if convention.lower() == 'energy':
         array *= 4. * _np.pi
